# $Id$

package User::utent;

$VERSION = '0.01';

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);

require Exporter;
require DynaLoader;

use Carp ();

@ISA		= qw(Exporter DynaLoader);
@EXPORT		= qw();
@EXPORT_OK	= qw();

%EXPORT_TAGS = (
    'type'	=> [qw(EMPTY RUN_LVL BOOT_TIME OLD_TIME NEW_TIME
			INIT_PROCESS LOGIN_PROCESS USER_PROCESS
			DEAD_PROCESS ACCOUNTING FTP REMOTE_LOGIN
			REMOTE_PROCESS AUTOLOG UTMAXTYPE)],

    'msg'	=> [qw(RUNLVL_MSG BOOT_MSG OTIME_MSG NTIME_MSG)],

    'path'	=> [qw(ILOG_FILE UTMPX_FILE UTMP_FILE WTMPX_FILE
			WTMP_FILE LASTLOG_FILE)],
);

# Set up the safe-* tags.
for my $key (keys %EXPORT_TAGS) {
    $EXPORT_TAGS{"safe-$key"} = [ map { "UT_$_" } @{ $EXPORT_TAGS{$key} } ];
}

Exporter::export_ok_tags;

sub AUTOLOAD {
    my $constname;
    ($constname = $AUTOLOAD) =~ s/.*:://;
    my $val = constant($constname);
    if ($! != 0) {
	Carp::croak
	    $! =~ /Invalid/
		? "Undefined subroutine $AUTOLOAD called"
		: "Your vendor has not defined User::utent macro $constname";
    }
    eval "sub $AUTOLOAD { $val }";
    die if $@;
    goto &$AUTOLOAD;
}

bootstrap User::utent $VERSION;

1;

__END__

=head1 NAME

User::utent - Perl interface to utmp/utmpx/wtmp/wtmpx databases

=head1 SYNOPSIS

  use User::utent;

=head1 DESCRIPTION

This package provides an interface to the C functions and structures
used with the utmp and utmpx databases.

=head1 AUTHOR

Roderick Schertler <F<roderick@argon.org>>

=head1 SEE ALSO

perl(1), getutent(3), getutxent(3), utmp(4), utmpx(4).

=cut
